from setuptools import setup

import sys
from os.path import dirname, join
import subprocess

base_package = "dslogs"

setup_dir = dirname(__file__)
git_dir = join(setup_dir, ".git")
version_file = join(setup_dir, base_package, "version.py")

# Automatically generate a version.py based on the git version
p = subprocess.Popen(
    ["git", "describe", "--tags", "--long", "--dirty=-dirty"],
    stdout=subprocess.PIPE,
    stderr=subprocess.PIPE,
)
out, err = p.communicate()
# Make sure the git version has at least one tag
if err:
    print("Error: You need to create a tag for this repo to use the builder")
    sys.exit(1)

# Convert git version to PEP440 compliant version
# - Older versions of pip choke on local identifiers, so we can't include the git commit
version, commits, local = out.decode("utf-8").rstrip().split("-", 2)
if commits != "0" or "-dirty" in local:
    version = "%s.post0.dev%s" % (version, commits)

# Create the version.py file
with open(version_file, "w") as fp:
    fp.write("# Autogenerated by setup.py\n__version__ = '{0}'\n".format(version))

# read the contents of your README file
with open(join(setup_dir, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()


setup(
    name=base_package,
    version=version,
    description='FIRST FRC Driver Station log streamer',
    author='Paul Rensing',
    author_email='prensing@ligerbots.org',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='http://github.com/ligerbots/dslogparser',
    license='MIT',
    packages=['dslogs'],
    install_requires=['arrow', 'dslogparser'],
    keywords=['FRC', 'logfiles'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
    ]
)
